<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Microsoft.Graphics.Display

Windows Runtime (WinRT) APIs for for the `Microsoft.Graphics.Display` namespace.

This package provides the `winrt.microsoft.graphics.display` module.
